@@ -26,7 +26,7 @@ int exitcode;
 
 /* Check that NULL can be passed through varargs as a pointer type,
    per POSIX 2008.  */
-verify (sizeof (NULL) == sizeof (void *));
+verify (sizeof NULL == sizeof (void *));
 
 int
 main ()
