@@ -691,20 +691,20 @@ print_extensions (gnutls_string * str, const char *prefix, int type,
 		  cert_type_t cert)
 {
   int i, err;
+  int san_idx = 0;
+  int proxy_idx = 0;
+  int basic_idx = 0;
+  int keyusage_idx = 0;
+  int keypurpose_idx = 0;
+  int ski_idx = 0;
+  int aki_idx = 0;
+  int crldist_idx = 0;
 
   for (i = 0;; i++)
     {
       char oid[MAX_OID_SIZE] = "";
       size_t sizeof_oid = sizeof (oid);
       int critical;
-      size_t san_idx = 0;
-      size_t proxy_idx = 0;
-      size_t basic_idx = 0;
-      size_t keyusage_idx = 0;
-      size_t keypurpose_idx = 0;
-      size_t ski_idx = 0;
-      size_t aki_idx = 0;
-      size_t crldist_idx = 0;
 
       if (type == TYPE_CRT)
 	err = gnutls_x509_crt_get_extension_info (cert.crt, i,
@@ -959,15 +959,30 @@ print_cert (gnutls_string * str, gnutls_x509_crt_t cert, int notsigned)
   /* Issuer. */
   if (!notsigned)
     {
-      char dn[1024];
-      size_t dn_size = sizeof (dn);
+      char *dn;
+      size_t dn_size = 0;
       int err;
 
-      err = gnutls_x509_crt_get_issuer_dn (cert, dn, &dn_size);
-      if (err < 0)
+      err = gnutls_x509_crt_get_issuer_dn (cert, NULL, &dn_size);
+      if (err != GNUTLS_E_SHORT_MEMORY_BUFFER)
 	addf (str, "error: get_issuer_dn: %s\n", gnutls_strerror (err));
       else
-	addf (str, _("\tIssuer: %s\n"), dn);
+	{
+	  dn = gnutls_malloc (dn_size);
+	  if (!dn)
+	    addf (str, "error: malloc (%d): %s\n", (int) dn_size,
+		  gnutls_strerror (GNUTLS_E_MEMORY_ERROR));
+	  else
+	    {
+	      err = gnutls_x509_crt_get_issuer_dn (cert, dn, &dn_size);
+	      if (err < 0)
+		addf (str, "error: get_issuer_dn: %s\n",
+		      gnutls_strerror (err));
+	      else
+		addf (str, _("\tIssuer: %s\n"), dn);
+	      gnutls_free (dn);
+	    }
+	}
     }
 
   /* Validity. */
@@ -1007,15 +1022,30 @@ print_cert (gnutls_string * str, gnutls_x509_crt_t cert, int notsigned)
 
   /* Subject. */
   {
-    char dn[1024];
-    size_t dn_size = sizeof (dn);
+    char *dn;
+    size_t dn_size = 0;
     int err;
 
-    err = gnutls_x509_crt_get_dn (cert, dn, &dn_size);
-    if (err < 0)
+    err = gnutls_x509_crt_get_dn (cert, NULL, &dn_size);
+    if (err != GNUTLS_E_SHORT_MEMORY_BUFFER)
       addf (str, "error: get_dn: %s\n", gnutls_strerror (err));
     else
-      addf (str, _("\tSubject: %s\n"), dn);
+      {
+	dn = gnutls_malloc (dn_size);
+	if (!dn)
+	  addf (str, "error: malloc (%d): %s\n", (int) dn_size,
+		gnutls_strerror (GNUTLS_E_MEMORY_ERROR));
+	else
+	  {
+	    err = gnutls_x509_crt_get_dn (cert, dn, &dn_size);
+	    if (err < 0)
+	      addf (str, "error: get_dn: %s\n",
+		    gnutls_strerror (err));
+	    else
+	      addf (str, _("\tSubject: %s\n"), dn);
+	    gnutls_free (dn);
+	  }
+      }
   }
 
   /* SubjectPublicKeyInfo. */
@@ -1212,31 +1242,60 @@ print_other (gnutls_string * str, gnutls_x509_crt_t cert, int notsigned)
 static void
 print_oneline (gnutls_string * str, gnutls_x509_crt_t cert)
 {
-
   /* Subject. */
   {
-    char dn[1024];
-    size_t dn_size = sizeof (dn);
+    char *dn;
+    size_t dn_size = 0;
     int err;
 
-    err = gnutls_x509_crt_get_dn (cert, dn, &dn_size);
-    if (err < 0)
+    err = gnutls_x509_crt_get_dn (cert, NULL, &dn_size);
+    if (err != GNUTLS_E_SHORT_MEMORY_BUFFER)
       addf (str, "unknown subject (%s), ", gnutls_strerror (err));
     else
-      addf (str, "subject `%s', ", dn);
+      {
+	dn = gnutls_malloc (dn_size);
+	if (!dn)
+	  addf (str, "unknown subject (%s), ",
+		gnutls_strerror (GNUTLS_E_MEMORY_ERROR));
+	else
+	  {
+	    err = gnutls_x509_crt_get_dn (cert, dn, &dn_size);
+	    if (err < 0)
+	      addf (str, "unknown subject (%s), ",
+		    gnutls_strerror (err));
+	    else
+	      addf (str, "subject `%s', ", dn);
+	    gnutls_free (dn);
+	  }
+      }
   }
 
   /* Issuer. */
   {
-    char dn[1024];
-    size_t dn_size = sizeof (dn);
+    char *dn;
+    size_t dn_size = 0;
     int err;
 
-    err = gnutls_x509_crt_get_issuer_dn (cert, dn, &dn_size);
-    if (err < 0)
+    err = gnutls_x509_crt_get_issuer_dn (cert, NULL, &dn_size);
+    if (err != GNUTLS_E_SHORT_MEMORY_BUFFER)
       addf (str, "unknown issuer (%s), ", gnutls_strerror (err));
     else
-      addf (str, "issuer `%s', ", dn);
+      {
+	dn = gnutls_malloc (dn_size);
+	if (!dn)
+	  addf (str, "unknown issuer (%s), ",
+		gnutls_strerror (GNUTLS_E_MEMORY_ERROR));
+	else
+	  {
+	    err = gnutls_x509_crt_get_issuer_dn (cert, dn, &dn_size);
+	    if (err < 0)
+	      addf (str, "unknown issuer (%s), ",
+		    gnutls_strerror (err));
+	    else
+	      addf (str, "issuer `%s', ", dn);
+	    gnutls_free (dn);
+	  }
+      }
   }
 
   /* Key algorithm and size. */
@@ -1428,15 +1487,30 @@ print_crl (gnutls_string * str, gnutls_x509_crl_t crl, int notsigned)
   /* Issuer. */
   if (!notsigned)
     {
-      char dn[1024];
-      size_t dn_size = sizeof (dn);
+      char *dn;
+      size_t dn_size = 0;
       int err;
 
-      err = gnutls_x509_crl_get_issuer_dn (crl, dn, &dn_size);
-      if (err < 0)
+      err = gnutls_x509_crl_get_issuer_dn (crl, NULL, &dn_size);
+      if (err != GNUTLS_E_SHORT_MEMORY_BUFFER)
 	addf (str, "error: get_issuer_dn: %s\n", gnutls_strerror (err));
       else
-	addf (str, _("\tIssuer: %s\n"), dn);
+	{
+	  dn = gnutls_malloc (dn_size);
+	  if (!dn)
+	    addf (str, "error: malloc (%d): %s\n", (int) dn_size,
+		  gnutls_strerror (GNUTLS_E_MEMORY_ERROR));
+	  else
+	    {
+	      err = gnutls_x509_crl_get_issuer_dn (crl, dn, &dn_size);
+	      if (err < 0)
+		addf (str, "error: get_issuer_dn: %s\n",
+		      gnutls_strerror (err));
+	      else
+		addf (str, _("\tIssuer: %s\n"), dn);
+	    }
+	  gnutls_free (dn);
+	}
     }
 
   /* Validity. */
@@ -1481,14 +1555,14 @@ print_crl (gnutls_string * str, gnutls_x509_crl_t crl, int notsigned)
     {
       size_t i;
       int err = 0;
+      int aki_idx = 0;
+      int crl_nr = 0;
 
       for (i = 0;; i++)
 	{
 	  char oid[MAX_OID_SIZE] = "";
 	  size_t sizeof_oid = sizeof (oid);
 	  int critical;
-	  int crl_nr = 0;
-	  int aki_idx = 0;
 
 	  err = gnutls_x509_crl_get_extension_info (crl, i,
 						    oid, &sizeof_oid,
@@ -1742,15 +1816,30 @@ print_crq (gnutls_string * str, gnutls_x509_crq_t cert)
 
   /* Subject */
   {
-    char dn[1024];
-    size_t dn_size = sizeof (dn);
+    char *dn;
+    size_t dn_size = 0;
     int err;
 
-    err = gnutls_x509_crq_get_dn (cert, dn, &dn_size);
-    if (err < 0)
+    err = gnutls_x509_crq_get_dn (cert, NULL, &dn_size);
+    if (err != GNUTLS_E_SHORT_MEMORY_BUFFER)
       addf (str, "error: get_dn: %s\n", gnutls_strerror (err));
     else
-      addf (str, _("\tSubject: %s\n"), dn);
+      {
+	dn = gnutls_malloc (dn_size);
+	if (!dn)
+	  addf (str, "error: malloc (%d): %s\n", (int) dn_size,
+		gnutls_strerror (GNUTLS_E_MEMORY_ERROR));
+	else
+	  {
+	    err = gnutls_x509_crq_get_dn (cert, dn, &dn_size);
+	    if (err < 0)
+	      addf (str, "error: get_dn: %s\n",
+		    gnutls_strerror (err));
+	    else
+	      addf (str, _("\tSubject: %s\n"), dn);
+	    gnutls_free (dn);
+	  }
+      }
   }
 
   /* SubjectPublicKeyInfo. */
@@ -1830,13 +1919,13 @@ print_crq (gnutls_string * str, gnutls_x509_crq_t cert)
   {
     size_t i;
     int err = 0;
+    int extensions = 0;
+    int challenge = 0;
 
     for (i = 0;; i++)
       {
 	char oid[MAX_OID_SIZE] = "";
 	size_t sizeof_oid = sizeof (oid);
-	int extensions = 0;
-	int challenge = 0;
 
 	err = gnutls_x509_crq_get_attribute_info (cert, i, oid, &sizeof_oid);
 	if (err < 0)
