@@ -32,21 +32,6 @@
 #include <gnutls/gnutls.h>
 #include <gnutls/x509.h>
 
-/* GnuTLS internally calls time() to find out the current time when
-   verifying certificates.  To avoid a time bomb, we hard code the
-   current time.  This should work fine on systems where the library
-   call to time is resolved at run-time.  */
-time_t
-time (time_t *t)
-{
-  time_t then = 1256803113;
-
-  if (t)
-    *t = then;
-
-  return then;
-}
-
 /* *INDENT-OFF* */
 
 /* Triggers incorrect verification success on older versions */
@@ -716,11 +701,8 @@ static struct
   { "rsa-md5 not ok", mayfirst_chain, &mayfirst_chain[1],
     GNUTLS_VERIFY_ALLOW_SIGN_RSA_MD2,
     GNUTLS_CERT_INSECURE_ALGORITHM | GNUTLS_CERT_INVALID },
-  { "rsa-md5 not ok2", mayfirst_chain, &mayfirst_chain[1],
-    GNUTLS_VERIFY_ALLOW_SIGN_RSA_MD5,
-    GNUTLS_CERT_EXPIRED | GNUTLS_CERT_INVALID },
   { "rsa-md5 ok", mayfirst_chain, &mayfirst_chain[1],
-    GNUTLS_VERIFY_DISABLE_TIME_CHECKS | GNUTLS_VERIFY_ALLOW_SIGN_RSA_MD5, 0 },
+    GNUTLS_VERIFY_ALLOW_SIGN_RSA_MD5, 0 },
   { "v1ca fail", v1ca, &v1ca[2],
     0, GNUTLS_CERT_SIGNER_NOT_CA | GNUTLS_CERT_INVALID },
   { "v1ca expired", v1ca, &v1ca[2],
@@ -779,15 +761,15 @@ main (int argc, char *argv[])
       gnutls_datum_t tmp;
       size_t j;
 
-      printf ("Chain '%s' (%d)...\n", chains[i].name, i);
+      printf ("Chain '%s' (%d)...\n", chains[i].name, (int)i);
 
       for (j = 0; chains[i].chain[j]; j++)
 	{
-	  printf ("\tAdding certificate %d...", j);
+	  printf ("\tAdding certificate %d...", (int)j);
 
 	  ret = gnutls_x509_crt_init (&certs[j]);
 	  if (ret < 0)
-	    error (EXIT_FAILURE, 0, "gnutls_x509_crt_init[%d,%d]: %s", i, j,
+	    error (EXIT_FAILURE, 0, "gnutls_x509_crt_init[%d,%d]: %s", (int)i, (int)j,
 		   gnutls_strerror (ret));
 
 	  tmp.data = (char *) chains[i].chain[j];
@@ -796,11 +778,11 @@ main (int argc, char *argv[])
 	  ret = gnutls_x509_crt_import (certs[j], &tmp, GNUTLS_X509_FMT_PEM);
 	  printf ("done\n");
 	  if (ret < 0)
-	    error (EXIT_FAILURE, 0, "gnutls_x509_crt_import[%d,%d]: %s", i, j,
+	    error (EXIT_FAILURE, 0, "gnutls_x509_crt_import[%d,%d]: %s", (int)i, (int)j,
 		   gnutls_strerror (ret));
 
 	  gnutls_x509_crt_print (certs[j], GNUTLS_CRT_PRINT_ONELINE, &tmp);
-	  printf ("\tCertificate %d: %.*s\n", j, tmp.size, tmp.data);
+	  printf ("\tCertificate %d: %.*s\n", (int)j, tmp.size, tmp.data);
 	  gnutls_free (tmp.data);
 	}
 
