@@ -206,7 +206,7 @@ server_start (void)
   sa_serv.sin_addr.s_addr = INADDR_ANY;
   sa_serv.sin_port = htons (PORT);	/* Server Port number */
 
-  setsockopt (listen_sd, SOL_SOCKET, SO_REUSEADDR, &optval, sizeof (int));
+  setsockopt (listen_sd, SOL_SOCKET, SO_REUSEADDR, (void *) &optval, sizeof (int));
 
   err = bind (listen_sd, (SA *) & sa_serv, sizeof (sa_serv));
   if (err == -1)
@@ -264,7 +264,7 @@ server (void)
   i = 0;
   for (;;)
     {
-      bzero (buffer, MAX_BUF + 1);
+      memset (buffer, 0, MAX_BUF + 1);
       ret = gnutls_record_recv (session, buffer, MAX_BUF);
 
       if (ret == 0)
