@@ -88,7 +88,7 @@ client (struct params_res *params)
   /* variables used in session resuming
    */
   int t;
-  gnutls_datum session_data;
+  gnutls_datum_t session_data;
 
   gnutls_global_init ();
 
@@ -216,7 +216,7 @@ client (struct params_res *params)
 
 /* These are global */
 gnutls_anon_server_credentials_t anoncred;
-gnutls_datum_t session_ticket_key;
+gnutls_datum_t session_ticket_key = { NULL, 0 };
 
 static gnutls_session_t
 initialize_tls_session (struct params_res *params)
@@ -421,6 +421,9 @@ server (struct params_res *params)
       wrap_db_deinit ();
     }
 
+  gnutls_free (session_ticket_key.data);
+  session_ticket_key.data = NULL;
+
   success ("server: finished\n");
 }
 
@@ -457,7 +460,7 @@ doit (void)
       else
 	{
 	  client (&resume_tests[i]);
-	  global_stop ();
+	  gnutls_global_deinit ();
 	  exit (0);
 	}
     }
